<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/XSL/Transform"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                              xmlns:wwenv="urn:WebWorks-XSLT-Extension-Environment"
                              xmlns:wwexec="urn:WebWorks-XSLT-Extension-Execute"
                              xmlns:wwexsldoc="urn:WebWorks-XSLT-Extension-Document"
                              xmlns:wwfilesystem="urn:WebWorks-XSLT-Extension-FileSystem"
                              xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
                              xmlns:wwprogress="urn:WebWorks-XSLT-Extension-Progress"
                              xmlns:wwstring="urn:WebWorks-XSLT-Extension-StringUtilities"
                              xmlns:wwuri="urn:WebWorks-XSLT-Extension-URI"
                              exclude-result-prefixes="xsl msxsl wwenv wwexec wwexsldoc wwfilesystem wwlog wwprogress wwstring wwuri"
>
 <xsl:template name="Write_DITA_Batch_File">
  <xsl:param name="ParamBatchFilePath" />
  <xsl:param name="ParamAntTarget" />
  <xsl:param name="ParamInput" />
  <xsl:param name="ParamOutput" />

  <!-- Aborted? -->
  <!--          -->
  <xsl:if test="not(wwprogress:Abort())">
   <!-- Locate adapter requirements -->
   <!--                             -->
   <xsl:variable name="VarWebWorksAntXslHome" select="wwuri:AsFilePath('wwxmladapter:scripts/dita/ant/xsl')" />
   <xsl:variable name="VarDefaultWWConfigPath" select="wwuri:AsFilePath('wwxmladapter:scripts/dita/default.wwconfig')" />
   <xsl:variable name="VarAntBuildFilePath" select="wwuri:AsFilePath('wwxmladapter:scripts/dita/ant/webworks.xml')" />

   <!-- Locate tools -->
   <!--              -->
   <xsl:variable name="VarJavaHome" select="wwfilesystem:GetShortPathName(wwenv:JDKHome())" />
   <xsl:variable name="VarAntPath" select="wwuri:AsFilePath('wwhelper:apache-ant/bin/ant')" />
   <xsl:variable name="VarAntHome" select="wwfilesystem:GetShortPathName(wwuri:AsFilePath('wwhelper:apache-ant'))" />
   <xsl:variable name="VarSaxonHome" select="wwfilesystem:GetShortPathName(wwuri:AsFilePath('wwhelper:saxon'))" />
   <xsl:variable name="VarFOPHome" select="wwfilesystem:GetShortPathName(wwuri:AsFilePath('wwhelper:apache-fop'))" />
   <xsl:variable name="VarDITAOTHome" select="wwfilesystem:GetShortPathName(wwuri:AsFilePath('wwhelper:dita-ot'))" />

   <xsl:choose>
    <!-- JavaHome is defined -->
    <!--                     -->
    <xsl:when test="string-length($VarJavaHome) &gt; 0">
     <!-- Define build batch file -->
     <!--                         -->
     <xsl:variable name="VarBatchFileContentsAsXML">
set ANT_TOOL=&quot;<xsl:value-of select="$VarAntPath" />&quot;
set ANT_BUILD_FILE=&quot;<xsl:value-of select="$VarAntBuildFilePath" />&quot;
set ANT_TARGET=&quot;<xsl:value-of select="$ParamAntTarget" />&quot;
set WEBWORKS_ANT_XSL_HOME=&quot;<xsl:value-of select="$VarWebWorksAntXslHome" />&quot;
set INPUT=&quot;<xsl:value-of select="$ParamInput" />&quot;
set OUTPUT=&quot;<xsl:value-of select="$ParamOutput" />&quot;

set JAVA_HOME=&quot;<xsl:value-of select="$VarJavaHome" />&quot;
set ANT_HOME=<xsl:value-of select="$VarAntHome" />
set SAXON_HOME=&quot;<xsl:value-of select="$VarSaxonHome" />&quot;
set FOP_HOME=&quot;<xsl:value-of select="$VarFOPHome" />&quot;
set DITA_OT_HOME=&quot;<xsl:value-of select="$VarDITAOTHome" />&quot;

set PATH=%JAVA_HOME%\bin;%PATH%

set CLASSPATH=%DITA_OT_HOME%\lib;%CLASSPATH%
set CLASSPATH=%DITA_OT_HOME%\lib\dost.jar;%CLASSPATH%
set CLASSPATH=%DITA_OT_HOME%\lib\resolver.jar;%CLASSPATH%
set CLASSPATH=%SAXON_HOME%\saxon.jar;%CLASSPATH%
set CLASSPATH=%SAXON_HOME%\saxon-jdom.jar;%CLASSPATH%

set ANT_OPTS=-Djavax.xml.transform.TransformerFactory=com.icl.saxon.TransformerFactoryImpl

set DEFAULT_WWCONFIG_PATH=&quot;<xsl:value-of select="$VarDefaultWWConfigPath" />&quot;

%ANT_TOOL% -buildfile %ANT_BUILD_FILE% %ANT_TARGET% -Dargs.ditadir=%DITA_OT_HOME% -Dargs.ant.xsl.dir=%WEBWORKS_ANT_XSL_HOME% -Dargs.default.wwconfig.path=%DEFAULT_WWCONFIG_PATH% -Dargs.fopdir=%FOP_HOME% -Dargs.input=%INPUT% -Dargs.output=%OUTPUT%
     </xsl:variable>
     <xsl:variable name="VarBatchFileContents" select="msxsl:node-set($VarBatchFileContentsAsXML)" />

     <!-- Determine correct encoding to use -->
     <!--                                   -->
     <xsl:variable name="VarCurrentUILocale" select="substring(wwenv:CurrentUILocale(), 1, 2)" />
     <xsl:variable name="VarEncoding">
      <xsl:choose>
       <xsl:when test="$VarCurrentUILocale = 'ja'">
        <xsl:text>Shift_JIS</xsl:text>
       </xsl:when>

       <xsl:otherwise>
        <xsl:text>Windows-1252</xsl:text>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:variable>

     <!-- Write build batch file -->
     <!--                        -->
     <xsl:variable name="VarWriteResult" select="wwexsldoc:Document($VarBatchFileContentsAsXML, $ParamBatchFilePath, $VarEncoding, 'text')" />
    </xsl:when>

    <!-- JavaHome is not defined -->
    <!--                         -->
    <xsl:otherwise>
     <xsl:variable name="VarQueueAlert" select="wwprogress:QueueAlert('Java SDK not found!')" />
     <xsl:variable name="VarCancel" select="wwprogress:Cancel()" />
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>


 <xsl:template name="Write_FOP_Batch_File">
  <xsl:param name="ParamBatchFilePath" />
  <xsl:param name="ParamInput" />
  <xsl:param name="ParamOutputFormat" />
  <xsl:param name="ParamOutput" />

  <!-- Aborted? -->
  <!--          -->
  <xsl:if test="not(wwprogress:Abort())">
   <!-- Locate tools -->
   <!--              -->
   <xsl:variable name="VarJavaHome" select="wwfilesystem:GetShortPathName(wwenv:JDKHome())" />
   <xsl:variable name="VarFOPHome" select="wwfilesystem:GetShortPathName(wwuri:AsFilePath('wwhelper:apache-fop'))" />

   <xsl:choose>
    <!-- JavaHome is defined -->
    <!--                     -->
    <xsl:when test="string-length($VarJavaHome) &gt; 0">
     <!-- Define build batch file -->
     <!--                         -->
     <xsl:variable name="VarBatchFileContentsAsXML">
set JAVA_HOME=<xsl:value-of select="$VarJavaHome" />
set FOP_HOME=<xsl:value-of select="$VarFOPHome" />

set JAVACMD=%JAVA_HOME%\bin\java.exe

set LOGCHOICE=-Dorg.apache.commons.logging.Log=org.apache.commons.logging.impl.SimpleLog
set LOGLEVEL=-Dorg.apache.commons.logging.simplelog.defaultlog=INFO

set LIBDIR=%LOCAL_FOP_HOME%lib

set CLASSPATH_OPTION=%FOP_HOME%\build\fop.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\avalon-framework-4.2.0.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\batik-all-1.6.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\commons-io-1.1.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\commons-logging-1.0.4.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\serializer-2.7.0.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\xalan-2.7.0.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\xercesImpl-2.7.1.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\xml-apis-1.3.02.jar
set CLASSPATH_OPTION=%CLASSPATH_OPTION%;%FOP_HOME%\lib\xmlgraphics-commons-1.1.jar

&quot;%JAVACMD%&quot; %LOGCHOICE% %LOGLEVEL% -cp &quot;%CLASSPATH_OPTION%&quot; org.apache.fop.cli.Main &quot;<xsl:value-of select="$ParamInput" />&quot; &quot;<xsl:value-of select="$ParamOutputFormat" />&quot; &quot;<xsl:value-of select="$ParamOutput" />&quot;
     </xsl:variable>
     <xsl:variable name="VarBatchFileContents" select="msxsl:node-set($VarBatchFileContentsAsXML)" />

     <!-- Determine correct encoding to use -->
     <!--                                   -->
     <xsl:variable name="VarCurrentUILocale" select="substring(wwenv:CurrentUILocale(), 1, 2)" />
     <xsl:variable name="VarEncoding">
      <xsl:choose>
       <xsl:when test="$VarCurrentUILocale = 'ja'">
        <xsl:text>Shift_JIS</xsl:text>
       </xsl:when>

       <xsl:otherwise>
        <xsl:text>Windows-1252</xsl:text>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:variable>

     <!-- Write build batch file -->
     <!--                        -->
     <xsl:variable name="VarWriteResult" select="wwexsldoc:Document($VarBatchFileContentsAsXML, $ParamBatchFilePath, $VarEncoding, 'text')" />
    </xsl:when>

    <!-- JavaHome is not defined -->
    <!--                         -->
    <xsl:otherwise>
     <xsl:variable name="VarQueueAlert" select="wwprogress:QueueAlert('Java SDK not found!')" />
     <xsl:variable name="VarCancel" select="wwprogress:Cancel()" />
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>


 <xsl:template name="Execute_Batch_File">
  <xsl:param name="ParamBatchFilePath" />

  <!-- Aborted? -->
  <!--          -->
  <xsl:choose>
   <!-- Process -->
   <!--         -->
   <xsl:when test="not(wwprogress:Abort())">
    <!-- Execute -->
    <!--         -->
    <xsl:variable name="VarExecuteResult" select="wwexec:ExecuteCommand($ParamBatchFilePath)" />

    <!-- Log result -->
    <!--            -->
    <xsl:if test="string-length($VarExecuteResult/wwexec:Result/wwexec:Stream[@name = 'Output']/text()) &gt; 0">
     <xsl:choose>
      <xsl:when test="$VarExecuteResult/wwexec:Result/@retcode = 0">
       <!-- Nothing to do -->
       <!--               -->
      </xsl:when>

      <xsl:otherwise>
       <xsl:variable name="VarIgnoreOutput" select="wwlog:Warning(wwstring:Replace($VarExecuteResult/wwexec:Result/wwexec:Stream[@name = 'Output']/text(), '&#13;&#10;&#13;&#10;', '&#13;&#10;'))" />
      </xsl:otherwise>
     </xsl:choose>
    </xsl:if>
    <xsl:if test="string-length($VarExecuteResult/wwexec:Result/wwexec:Stream[@name = 'Error']/text()) &gt; 0">
     <xsl:variable name="VarIgnoreError" select="wwlog:Warning(wwstring:Replace($VarExecuteResult/wwexec:Result/wwexec:Stream[@name = 'Error']/text(), '&#13;&#10;&#13;&#10;', '&#13;&#10;'))" />
    </xsl:if>

    <!-- Return retcode -->
    <!--                -->
    <xsl:value-of select="$VarExecuteResult/wwexec:Result/@retcode" />
   </xsl:when>

   <!-- Abort -->
   <!--       -->
   <xsl:otherwise>
    <!-- Return retcode -->
    <!--                -->
    <xsl:value-of select="-1" />
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>
</xsl:stylesheet>
